package uebung01;

import java.io.BufferedReader;
import java.io.BufferedWriter;
import java.io.File;
import java.io.FileNotFoundException;
import java.io.FileReader;
import java.io.FileWriter;
import java.io.IOException;
import java.time.LocalDateTime;

/**
 * 
 * @author lorenz schauer
 * 
 * Konto-Klasse
 * Mit Schreibfunktion auf Log-Datei, die entsprechend angelegt wird, falls sie nicht existiert. 
 *
 */
public class Konto {

	private String kontonummer;
	private double kontostand;
	
	// Feldvariablen fr File, Lese- und Schreibe Streams
	private File logFile;
	private BufferedReader reader = null;
	private BufferedWriter writer = null;
	
	// Konstruktor
	public Konto(String kontonummer, double kontostand) {
		super();
		this.kontonummer = kontonummer;
		this.kontostand = kontostand;
		
		// Log-Datei:
		logFile = new File("log-File-ktn_"+kontonummer+".txt");
		if(!logFile.exists()){		
			try {
				// anlegen, falls nicht existiert.
				logFile.createNewFile();
			} catch (IOException e) {
				// TODO Auto-generated catch block
				e.printStackTrace();
			}
		}
	}

	public void einzahlen(double betrag){
		
		this.kontostand+=betrag;
		
		// Nachdem der Betrag eingezahlt wurde erfolgt Eintrag in die Logfile:
		try {
			writer = new BufferedWriter(new FileWriter(logFile,true)); // Eintrag wird dan Inhalt angehngt
			
			writer.write(LocalDateTime.now().toString()+": Einzahlung auf Konto "+this.kontonummer+": "+betrag+" Euro.\n");
			
			writer.close();
		} catch (IOException e) {
			// TODO Auto-generated catch block
			e.printStackTrace();
		}finally{
			if (writer!=null)
				try {
					writer.close(); // Nicht vergessen Stream auf jeden Fall zu schlieen!
				} catch (IOException e) {
					e.printStackTrace();
				}
		}
		
	}
	
	public void auszahlen(double betrag){
		this.kontostand-=betrag;
		
		// Nachdem der Betrag ausgezahlt wurde erfolgt Eintrag in die Log-File:
		try {
			writer = new BufferedWriter(new FileWriter(logFile,true));
			writer.write(LocalDateTime.now().toString()+": Auszahlung vom Konto "+this.kontonummer+": "+betrag+" Euro.\n");
			writer.close();
		} catch (IOException e) {
			// TODO Auto-generated catch block
			e.printStackTrace();
		}finally{
			if (writer!=null)
				try {
					writer.close(); 
				} catch (IOException e) {
					// TODO Auto-generated catch block
					e.printStackTrace();
				}
		}
	}
	
	
	public String getKontonummer() {
		return kontonummer;
	}

	public double getKontostand() {
		return kontostand;
	}
	
	public void seeLogFile(){
		
		System.out.println("Printing Log-File...");
		System.out.println("");
		
		try {
			reader = new BufferedReader(new FileReader(this.logFile));
			String line; 
			while((line=reader.readLine())!=null){
				System.out.println(line);
			}
			reader.close();
		} catch (FileNotFoundException e) {
			// TODO Auto-generated catch block
			e.printStackTrace();
		} catch (IOException e) {
			// TODO Auto-generated catch block
			e.printStackTrace();
		}finally{
			if(reader!=null){
				try {
					reader.close();
				} catch (IOException e) {
					// TODO Auto-generated catch block
					e.printStackTrace();
				}
			}
		}
	}
	
}
